@@ -28,7 +28,7 @@ using namespace KgpgCore;
 
 GroupEditProxyModel::GroupEditProxyModel(QObject *parent, const bool invert, QList<KGpgNode *> *ids, const KgpgCore::KgpgKeyTrust mintrust)
 	: QSortFilterProxyModel(parent),
-	m_model(Q_NULLPTR),
+	m_model(nullptr),
 	m_invert(invert),
 	m_ids(ids),
 	m_mintrust(mintrust)
@@ -81,7 +81,7 @@ GroupEditProxyModel::rowCount(const QModelIndex &parent) const
 		return 0;
 	if (parent.isValid())
 		return 0;
-	if (m_model == Q_NULLPTR)
+	if (m_model == nullptr)
 		return 0;
 	return QSortFilterProxyModel::rowCount(parent);
 }
@@ -119,6 +119,7 @@ GroupEditProxyModel::data(const QModelIndex &index, int role) const
 		default:
 			break;
 		}
+		break;
 	case Qt::DecorationRole:
 		if (index.column() != 1)
 			break;
@@ -133,7 +134,7 @@ GroupEditProxyModel::data(const QModelIndex &index, int role) const
 bool
 GroupEditProxyModel::hasChildren(const QModelIndex &parent) const
 {
-	if (m_model == Q_NULLPTR)
+	if (m_model == nullptr)
 		return false;
 	if (parent.column() > 0)
 		return false;
@@ -149,7 +150,7 @@ GroupEditProxyModel::headerData(int section, Qt::Orientation orientation, int ro
 	if (orientation != Qt::Horizontal)
 		return QVariant();
 
-	if (m_model == Q_NULLPTR)
+	if (m_model == nullptr)
 		return QVariant();
 
 	switch (section) {
